@@ -10,4 +10,9 @@ class RetryMaxCountDone(RequestErrorBase):
 
 class ResponseHasNoContent(RequestErrorBase):
     '''Response has no contents
+    '''
+
+
+class RotateProxiesDone(RequestErrorBase):
+    '''Rotate all Proxies list
     '''
\ No newline at end of file
