@@ -1,12 +1,9 @@
 import os
 from urllib.parse import urlparse, urlunparse, parse_qsl, parse_qs, urljoin
 
-import uncurl
 
 
 def abs_path(root, url):
-    # print('abs_path:root', root)
-    # print('abs_path:url', url)
     return urljoin(root, url)
 
 
@@ -53,17 +50,3 @@ def filter_params(url, fields):
     p = urlparse(url)
     args = p.scheme, p.netloc, p.path, p.params, qs, p.fragment
     return urlunparse(args)
-
-
-
-  
-def parse_curl(curl):
-    parsed = uncurl.parse_context(curl)
-    return dict(
-        url=parsed.url,
-        method=parsed.method,
-        qs=parse_query(parsed.url),
-        headers=dict(parsed.headers),
-        payloads=parsed.data,
-        cookies=dict(parsed.cookies)
-    )
\ No newline at end of file
