@@ -14,7 +14,7 @@ from eurosatory.crawler import test_eurosatory
 from dcinside.crawler import test_dcinside_crawler
 from exposeguridadmexico.crawler import test_expo_guarid
 from coupang.reviews import crawl_coupang_review
-
+from afreeca import cast
 
 def main():
     argparser = argparse.ArgumentParser(
@@ -77,5 +77,8 @@ def main():
     if args.appname == 'coupang':
         crawl_coupang_review(page_range=(2, 2))
 
+    if args.appname == 'afreeca':
+        cast.test()
+
 if __name__ == '__main__':
     main()
\ No newline at end of file
